@@ -3,11 +3,11 @@ package DBIx::dbMan::Extension::CmdHelp;
 use strict;
 use base 'DBIx::dbMan::Extension';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 1;
 
-sub IDENTIFICATION { return "000001-000009-000006"; }
+sub IDENTIFICATION { return "000001-000009-000007"; }
 
 sub preference { return 1000; }
 
@@ -21,9 +21,12 @@ sub handle_action {
 			$action{action} = 'HELP';
 			$action{type} = 'commands';
 			$action{what} = $1;
-		} elsif ($action{cmd} =~ /^show\s+versions?$/i) {
+		} elsif ($action{cmd} =~ /^(show\s+)?versions?$/i) {
 			$action{action} = 'HELP';
 			$action{type} = 'version';
+		} elsif ($action{cmd} =~ /^(show\s+)?license$/i) {
+			$action{action} = 'HELP';
+			$action{type} = 'license';
 		}
 	}
 
@@ -34,13 +37,14 @@ sub handle_action {
 sub cmdhelp {
 	return [
 		'HELP' => 'Show this help',
-		'SHOW VERSION' => 'Show dbMan'."'".'s version'
+		'SHOW VERSION' => 'Show dbMan'."'".'s version',
+		'SHOW LICENSE' => 'Show dbMan'."'".'s license'
 	];
 }
 
 sub cmdcomplete {
 	my ($obj,$text,$line,$start) = @_;
-	return qw/VERSION/ if $line =~ /^\s*SHOW\s+[A-Z]*$/i;
+	return qw/VERSION LICENSE/ if $line =~ /^\s*SHOW\s+[A-Z]*$/i;
 	return qw/HELP SHOW/ if $line =~ /^\s*[A-Z]*$/i;
 	return ();
 }
