@@ -1,15 +1,13 @@
 package DBIx::dbMan::Extension::OracleSQL;
 
 use strict;
-use vars qw/$VERSION @ISA/;
-use DBIx::dbMan::Extension;
+use base 'DBIx::dbMan::Extension';
 
-$VERSION = '0.08';
-@ISA = qw/DBIx::dbMan::Extension/;
+our $VERSION = '0.09';
 
 1;
 
-sub IDENTIFICATION { return "000001-000038-000008"; }
+sub IDENTIFICATION { return "000001-000038-000009"; }
 
 sub preference { return 3999; }
 
